@@ -30,15 +30,16 @@ int rename_unlink(const char *path) {
   }
 
   do {
+    i = 0;
+
     while (i < 14) {
       c = random_char();
       if (isalnum((int) c)) {
-	*p = c;
-	p++;
+	p[i] = c;
 	i++;
       }
     }
-    *p = '\0';
+    p[i] = '\0';
   } while (lstat(new_name, &statbuf) == 0);
 
   if (rename(path, new_name) == -1)
