@@ -128,9 +128,22 @@ int sunlink(const char *path, const int simple) {
 
 #endif /* HAVE_LINUX_EXT2_FS_H */
 
-  /* Groan - Tru64 has a different chflags in libc. This will band-aid
-     things until a better platform detection idea crops up. */
-#if HAVE_CHFLAGS && !(defined(__digital__) && defined(__unix__))
+/* chflags(2) turns out to be a different system call in every BSD
+   derivative. The important thing is to make sure we'll be able to
+   unlink it after we're through messing around. Unlinking it first
+   would remove the need for any of these checks, but would leave the
+   user with no way to overwrite the file if the process was
+   interupted during the overwriting. So, instead we assume that the
+   open() above will fail on immutable and append-only files and try
+   and catch only platforms supporting NOUNLINK here.
+
+   OpenBSD - doesn't support nounlink (As of 3.1)
+   FreeBSD - supports nounlink (from 4.4 on?)
+   Tru64 - unknown
+   MacOS X - unknown
+*/
+
+#if HAVE_CHFLAGS && __FreeBSD__
   if ((statbuf.st_flags & UF_IMMUTABLE) || 
       (statbuf.st_flags & UF_APPEND) ||
       (statbuf.st_flags & UF_NOUNLINK) || 
